@@ -1,5 +1,8 @@
 package Media::Info;
 
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -10,8 +13,6 @@ our @EXPORT_OK = qw(
                        get_media_info
                );
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 $SPEC{get_media_info} = {
@@ -33,7 +34,7 @@ sub get_media_info {
 }
 
 1;
-# ABSTRACT: Return information on media (music, video, etc) file/URL
+# ABSTRACT: Return information on media file/URL
 
 __END__
 
@@ -43,11 +44,11 @@ __END__
 
 =head1 NAME
 
-Media::Info - Return information on media (music, video, etc) file/URL
+Media::Info - Return information on media file/URL
 
 =head1 VERSION
 
-This document describes version 0.07 of Media::Info (from Perl distribution Media-Info), released on 2014-11-28.
+This document describes version 0.08 of Media::Info (from Perl distribution Media-Info), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -96,8 +97,6 @@ Media file/URL.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -107,7 +106,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 SEE ALSO
 
@@ -122,7 +121,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Media-Info
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Media-Info>.
+Source repository is at L<https://github.com/perlancar/perl-Media-Info>.
 
 =head1 BUGS
 
@@ -138,7 +137,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
